aboutsummaryrefslogtreecommitdiffstats
path: root/widgets/misc/e-canvas-vbox.h
diff options
context:
space:
mode:
Diffstat (limited to 'widgets/misc/e-canvas-vbox.h')
-rw-r--r--widgets/misc/e-canvas-vbox.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/widgets/misc/e-canvas-vbox.h b/widgets/misc/e-canvas-vbox.h
index b41b8f80ec..9fb5b8ba34 100644
--- a/widgets/misc/e-canvas-vbox.h
+++ b/widgets/misc/e-canvas-vbox.h
@@ -34,9 +34,9 @@ G_BEGIN_DECLS
*
* name type read/write description
* --------------------------------------------------------------------------------
* width double RW width of the CanvasVbox
* height double R height of the CanvasVbox
* spacing double RW Spacing between items.
*/
#define E_CANVAS_VBOX_TYPE (e_canvas_vbox_get_type ())
@@ -55,10 +55,10 @@ struct _ECanvasVbox
/* item specific fields */
GList *items; /* Of type GnomeCanvasItem */
- double width;
- double minimum_width;
- double height;
- double spacing;
+ gdouble width;
+ gdouble minimum_width;
+ gdouble height;
+ gdouble spacing;
};
struct _ECanvasVboxClass
@@ -34,9 +34,9 @@ G_BEGIN_DECLS
* name type read/write description
* --------------------------------------------------------------------------------
- * width double RW width of the CanvasVbox
- * height double R height of the CanvasVbox
- * spacing double RW Spacing between items.
+ * width gdouble RW width of the CanvasVbox
+ * height gdouble R height of the CanvasVbox
+ * spacing gdouble RW Spacing between items.
*/
#define E_CANVAS_VBOX_TYPE (e_canvas_vbox_get_type ())